@@ -2,6 +2,7 @@
 module OpenCascade.BRepBuilderAPI.MakeShape
 ( MakeShape
 , shape
+, build
 ) where
 import OpenCascade.BRepBuilderAPI.Types
 import qualified OpenCascade.TopoDS as TopoDS
@@ -12,4 +13,6 @@ import Data.Acquire
 foreign import capi unsafe "hs_BRepBuilderAPI_MakeShape.h hs_BRepBuilderAPI_MakeShape_shape" rawShape :: Ptr MakeShape -> IO (Ptr TopoDS.Shape)
 
 shape :: Ptr MakeShape -> Acquire (Ptr TopoDS.Shape)
-shape builder = mkAcquire (rawShape builder) (deleteShape)  
\ No newline at end of file
+shape builder = mkAcquire (rawShape builder) (deleteShape)  
+
+foreign import capi unsafe "hs_BRepBuilderAPI_MakeShape.h hs_BRepBuilderAPI_MakeShape_build" build :: Ptr MakeShape -> IO ()
\ No newline at end of file
