@@ -3,6 +3,7 @@
 module OpenCascade.BRepOffsetAPI.Types
 ( MakePipe
 , MakeOffsetShape
+, ThruSections
 ) where
 
 import qualified OpenCascade.Inheritance as Inheritance
@@ -10,6 +11,8 @@ import OpenCascade.BRepBuilderAPI.MakeShape (MakeShape)
 
 data MakePipe
 data MakeOffsetShape
+data ThruSections
 
 instance Inheritance.SubTypeOf MakeShape MakePipe
-instance Inheritance.SubTypeOf MakeShape MakeOffsetShape
\ No newline at end of file
+instance Inheritance.SubTypeOf MakeShape MakeOffsetShape
+instance Inheritance.SubTypeOf MakeShape ThruSections
\ No newline at end of file
