@@ -1,5 +1,20 @@
 {-# LANGUAGE EmptyDataDecls #-}
-module OpenCascade.GP.Types where
+module OpenCascade.GP.Types
+( Pnt
+, Pnt2d
+, Ax1
+, Ax2
+, Ax2d
+, Ax3
+, Dir
+, Dir2d
+, Vec
+, Vec2d
+, Trsf
+, Trsf2d
+, GTrsf
+, XYZ
+) where
 
 data Pnt
 data Pnt2d
@@ -14,4 +29,4 @@ data Vec2d
 data Trsf
 data Trsf2d
 data GTrsf
-
+data XYZ
