@@ -3,6 +3,7 @@ module OpenCascade.Geom.Internal.Destructors
 ( deleteHandleCurve
 , deleteHandleTrimmedCurve
 , deleteHandleBezierCurve
+, deleteHandleBSplineCurve
 , deleteBezierCurve
 ) where
 
@@ -18,4 +19,6 @@ foreign import capi unsafe "hs_Geom_TrimmedCurve.h hs_delete_Handle_Geom_Trimmed
 
 foreign import capi unsafe "hs_Geom_BezierCurve.h hs_delete_Handle_Geom_BezierCurve" deleteHandleBezierCurve :: Ptr (Handle BezierCurve) -> IO ()
 
+foreign import capi unsafe "hs_Geom_BSplineCurve.h hs_delete_Handle_Geom_BSplineCurve" deleteHandleBSplineCurve :: Ptr (Handle BSplineCurve) -> IO ()
+
 foreign import capi unsafe "hs_Geom_BezierCurve.h hs_delete_Geom_BezierCurve" deleteBezierCurve :: Ptr BezierCurve -> IO ()
