@@ -1,6 +1,7 @@
 {-# LANGUAGE CApiFFI #-}
 module OpenCascade.TopoDS.Internal.Destructors 
 ( deleteShape
+, deleteBuilder
 ) where
 
 import OpenCascade.TopoDS.Types
@@ -9,4 +10,5 @@ import Foreign.Ptr
 
 foreign import capi unsafe "hs_TopoDS_Shape.h hs_delete_TopoDS_Shape" deleteShape :: Ptr Shape -> IO ()
 
+foreign import capi unsafe "hs_TopoDS_Builder.h hs_delete_TopoDS_Builder" deleteBuilder :: Ptr Builder -> IO ()
 
